@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de" sourcelanguage="en">
+<TS version="2.0" language="de">
 <context>
     <name>AddImage</name>
     <message>
-        <location filename="../src/add_image.cpp" line="77"/>
+        <location filename="../src/add_image.cpp" line="87"/>
         <source>Open Image</source>
         <translation>Bild auswählen</translation>
     </message>
@@ -12,42 +12,42 @@
 <context>
     <name>AppearanceDialog</name>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="55"/>
+        <location filename="../src/appearance_dialog.cpp" line="59"/>
         <source>Appearance</source>
         <translation>Erscheinungsbild</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="64"/>
+        <location filename="../src/appearance_dialog.cpp" line="68"/>
         <source>Options</source>
         <translation>Optionen</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="66"/>
+        <location filename="../src/appearance_dialog.cpp" line="70"/>
         <source>Beveled borders</source>
         <translation>Abgeschrägte Kanten</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="69"/>
+        <location filename="../src/appearance_dialog.cpp" line="73"/>
         <source>Drop shadows</source>
         <translation>Schlagschatten</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="73"/>
+        <location filename="../src/appearance_dialog.cpp" line="77"/>
         <source>Colors</source>
         <translation>Farben</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="92"/>
+        <location filename="../src/appearance_dialog.cpp" line="96"/>
         <source>Background:</source>
         <translation>Hintergrund:</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="93"/>
+        <location filename="../src/appearance_dialog.cpp" line="97"/>
         <source>Shadow:</source>
         <translation>Schatten:</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="94"/>
+        <location filename="../src/appearance_dialog.cpp" line="98"/>
         <source>Highlight:</source>
         <translation>Hervorgehoben:</translation>
     </message>
@@ -55,59 +55,59 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="183"/>
-        <location filename="../src/board.cpp" line="289"/>
-        <location filename="../src/board.cpp" line="357"/>
+        <location filename="../src/board.cpp" line="187"/>
+        <location filename="../src/board.cpp" line="293"/>
+        <location filename="../src/board.cpp" line="361"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="183"/>
-        <location filename="../src/board.cpp" line="289"/>
+        <location filename="../src/board.cpp" line="187"/>
+        <location filename="../src/board.cpp" line="293"/>
         <source>Missing image.</source>
         <translation>Bild nicht gefunden.</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="190"/>
-        <location filename="../src/board.cpp" line="265"/>
+        <location filename="../src/board.cpp" line="194"/>
+        <location filename="../src/board.cpp" line="269"/>
         <location filename="../src/main.cpp" line="146"/>
         <source>Please Wait</source>
         <translation>Bitte warten</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="212"/>
-        <location filename="../src/board.cpp" line="364"/>
+        <location filename="../src/board.cpp" line="216"/>
+        <location filename="../src/board.cpp" line="368"/>
         <source>Loading image...</source>
         <translation>Bild wird geladen...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="218"/>
+        <location filename="../src/board.cpp" line="222"/>
         <source>Generating puzzle...</source>
         <translation>Puzzle wird erzeugt...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="224"/>
-        <location filename="../src/board.cpp" line="238"/>
+        <location filename="../src/board.cpp" line="228"/>
+        <location filename="../src/board.cpp" line="242"/>
         <source>Creating pieces...</source>
         <translation>Teile werden erzeugt...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="277"/>
+        <location filename="../src/board.cpp" line="281"/>
         <source>Loading puzzle...</source>
         <translation>Puzzle wird geladen...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="302"/>
+        <location filename="../src/board.cpp" line="306"/>
         <source>Unknown data format</source>
         <translation>Unbekanntes Dateiformat</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="352"/>
+        <location filename="../src/board.cpp" line="356"/>
         <source>Unknown element &apos;%1&apos;</source>
         <translation>Unbekanntes Element &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="357"/>
+        <location filename="../src/board.cpp" line="361"/>
         <source>Error parsing XML file.
 
 %1</source>
@@ -116,22 +116,22 @@
 %1</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="368"/>
+        <location filename="../src/board.cpp" line="372"/>
         <source>Loading pieces...</source>
         <translation>Teile werden geladen...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="450"/>
+        <location filename="../src/board.cpp" line="454"/>
         <source>Retrieving pieces...</source>
         <translation>Teile werden geholt...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="988"/>
+        <location filename="../src/board.cpp" line="994"/>
         <source>Placing pieces...</source>
         <translation>Teile werden gelegt...</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="1318"/>
+        <location filename="../src/board.cpp" line="1326"/>
         <source>Success</source>
         <translation>Fertiggestellt</translation>
     </message>
@@ -175,22 +175,22 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="98"/>
+        <location filename="../src/locale_dialog.cpp" line="50"/>
         <source>Select application language:</source>
         <translation>Anwendungssprache auswählen:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="101"/>
+        <location filename="../src/locale_dialog.cpp" line="53"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Systemeinstellung&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="195"/>
+        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Note</source>
         <translation>Hinweis</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="195"/>
+        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
     </message>
@@ -215,7 +215,7 @@
     </message>
     <message>
         <location filename="../src/new_game_tab.cpp" line="132"/>
-        <location filename="../src/new_game_tab.cpp" line="382"/>
+        <location filename="../src/new_game_tab.cpp" line="383"/>
         <source>%L1 pieces</source>
         <translation>%L1 Teile</translation>
     </message>
@@ -244,7 +244,7 @@ There are saved games using this image that will also be removed.</source>
 Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls gelöscht werden.</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="492"/>
+        <location filename="../src/new_game_tab.cpp" line="493"/>
         <source>Untitled</source>
         <translation>Unbenannt</translation>
     </message>
@@ -338,6 +338,7 @@ Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls ge
     <message>
         <location filename="../src/main.cpp" line="147"/>
         <location filename="../src/window.cpp" line="50"/>
+        <location filename="../src/window.cpp" line="286"/>
         <source>Tetzle</source>
         <translation>Tetzle</translation>
     </message>
@@ -529,13 +530,23 @@ Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls ge
     </message>
     <message>
         <location filename="../src/window.cpp" line="285"/>
-        <source>About</source>
-        <translation>Info</translation>
+        <source>About Tetzle</source>
+        <translation>Info über Tetzle</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="285"/>
-        <source>&lt;center&gt;&lt;big&gt;&lt;b&gt;Tetzle %1&lt;/b&gt;&lt;/big&gt;&lt;br/&gt;A jigsaw puzzle with tetrominoes for pieces&lt;br/&gt;&lt;small&gt;Copyright &amp;copy; 2008-2011 Graeme Gott&lt;/small&gt;&lt;/center&gt;</source>
-        <translation>&lt;center&gt;&lt;big&gt;&lt;b&gt;Tetzle %1&lt;/b&gt;&lt;/big&gt;&lt;br/&gt;Eine Puzzlespiel mit Tetrominos als Puzzleteilen&lt;br/&gt;&lt;small&gt;Copyright &amp;copy; 2008-2011 Graeme Gott&lt;/small&gt;&lt;/center&gt;</translation>
+        <location filename="../src/window.cpp" line="287"/>
+        <source>A jigsaw puzzle with tetrominoes for pieces</source>
+        <translation>Eine Puzzlespiel mit Tetrominos als Puzzleteilen</translation>
+    </message>
+    <message>
+        <location filename="../src/window.cpp" line="288"/>
+        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
+        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
+    </message>
+    <message>
+        <location filename="../src/window.cpp" line="289"/>
+        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
+        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
     </message>
 </context>
 <context>
